test.function: Test Function

test.functionR Documentation

Test Function

Description

#'This function creates a table with the number of event for a given species. Input needed: - KORA.Photo.Output = "Nameofcsv.csv" KORA ouput with lynx or any other species observed (All have been IDed) Important Note: - The csv must be in the folder of the used RStudio Project - Date in the csv must be in '

Usage

test.function(KORA.Photo.Output, Event_length, species)

Arguments

#

Author: Luc Le Grand


CrocutaLupus/KORAtool documentation built on April 13, 2025, 10:03 p.m.